@@ -190,6 +190,7 @@ class SockpuppetConsumer(JsonWebsocketConsumer):
 
     def subscribe(self, data, **kwargs):
         name = self._get_channelname(data['channelName'])
+        logger.debug('Subscribe %s to %s', self.channel_name, name)
         async_to_sync(self.channel_layer.group_add)(
             name,
             self.channel_name
@@ -220,8 +221,7 @@ class SockpuppetConsumer(JsonWebsocketConsumer):
 
     def render_page(self, reflex):
         parsed_url = urlparse(reflex.url)
-        url_path = parsed_url.path + parsed_url.query
-        resolved = resolve(url_path)
+        resolved = resolve(parsed_url.path)
         view = resolved.func
 
         instance_variables = [
